@@ -169,8 +169,6 @@ class SpotifyLibraryProvider(base.BaseLibraryProvider):
                     translator.to_mopidy_track(t) for t in results.tracks()])
             future.set(search_result)
 
-        # Wait always returns None on python 2.6 :/
-        self.backend.spotify.connected.wait(self._timeout)
         if not self.backend.spotify.connected.is_set():
             logger.debug('Not connected: Spotify search cancelled')
             return SearchResult(uri='spotify:search')
