@@ -1,6 +1,9 @@
+from __future__ import unicode_literals
+
 from mopidy.frontends.mpd.protocol import handle_request
 from mopidy.frontends.mpd.exceptions import MpdUnknownCommand
 
+
 @handle_request(r'^command_list_begin$')
 def command_list_begin(context):
     """
@@ -18,17 +21,19 @@ def command_list_begin(context):
         returned. If ``command_list_ok_begin`` is used, ``list_OK`` is
         returned for each successful command executed in the command list.
     """
-    context.dispatcher.command_list = []
+    context.dispatcher.command_list_receiving = True
     context.dispatcher.command_list_ok = False
+    context.dispatcher.command_list = []
+
 
 @handle_request(r'^command_list_end$')
 def command_list_end(context):
     """See :meth:`command_list_begin()`."""
-    if context.dispatcher.command_list is False:
-        # Test for False exactly, and not e.g. empty list
+    if not context.dispatcher.command_list_receiving:
         raise MpdUnknownCommand(command='command_list_end')
+    context.dispatcher.command_list_receiving = False
     (command_list, context.dispatcher.command_list) = (
-        context.dispatcher.command_list, False)
+        context.dispatcher.command_list, [])
     (command_list_ok, context.dispatcher.command_list_ok) = (
         context.dispatcher.command_list_ok, False)
     command_list_response = []
@@ -37,14 +42,16 @@ def command_list_end(context):
             command, current_command_list_index=index)
         command_list_response.extend(response)
         if (command_list_response and
-                command_list_response[-1].startswith(u'ACK')):
+                command_list_response[-1].startswith('ACK')):
             return command_list_response
         if command_list_ok:
-            command_list_response.append(u'list_OK')
+            command_list_response.append('list_OK')
     return command_list_response
 
+
 @handle_request(r'^command_list_ok_begin$')
 def command_list_ok_begin(context):
     """See :meth:`command_list_begin()`."""
-    context.dispatcher.command_list = []
+    context.dispatcher.command_list_receiving = True
     context.dispatcher.command_list_ok = True
+    context.dispatcher.command_list = []
