@@ -1,8 +1,10 @@
 from __future__ import unicode_literals
 
+import unittest
+
 from mopidy.backends.local import actor
 
-from tests import unittest, path_to_data_dir
+from tests import path_to_data_dir
 from tests.backends.base.library import LibraryControllerTest
 
 
