@@ -1,9 +1,10 @@
 from __future__ import unicode_literals
 
+import unittest
+
 from mopidy.core import PlaybackState
 from mopidy.models import Track
 
-from tests import unittest
 from tests.frontends.mpd import protocol
 
 
