@@ -1,5 +1,7 @@
 from __future__ import unicode_literals
 
+import unittest
+
 import pykka
 
 from mopidy import core
@@ -9,8 +11,6 @@ from mopidy.frontends.mpd import dispatcher
 from mopidy.frontends.mpd.protocol import status
 from mopidy.models import Track
 
-from tests import unittest
-
 
 PAUSED = PlaybackState.PAUSED
 PLAYING = PlaybackState.PLAYING
