@@ -1,18 +1,17 @@
 from __future__ import unicode_literals
 
 import platform
+import mock
+import unittest
 
 import pygst
 pygst.require('0.10')
 import gst
 
-import mock
 import pkg_resources
 
 from mopidy.utils import deps
 
-from tests import unittest
-
 
 class DepsTest(unittest.TestCase):
     def test_format_dependency_list(self):
