@@ -1,11 +1,10 @@
 from __future__ import unicode_literals
 
 from distutils.version import StrictVersion as SV
+import unittest
 
 from mopidy import __version__
 
-from tests import unittest
-
 
 class VersionTest(unittest.TestCase):
     def test_current_version_is_parsable_as_a_strict_version_number(self):
@@ -39,5 +38,6 @@ class VersionTest(unittest.TestCase):
         self.assertLess(SV('0.12.0'), SV('0.13.0'))
         self.assertLess(SV('0.13.0'), SV('0.14.0'))
         self.assertLess(SV('0.14.0'), SV('0.14.1'))
-        self.assertLess(SV('0.14.1'), SV(__version__))
-        self.assertLess(SV(__version__), SV('0.14.3'))
+        self.assertLess(SV('0.14.1'), SV('0.14.2'))
+        self.assertLess(SV('0.14.2'), SV(__version__))
+        self.assertLess(SV(__version__), SV('0.15.1'))
